@@ -1,4 +1,4 @@
 from .JsonHandler import *
 from .responseContentParser import *
 from .daleeImageCreate import *
-from .clipit import *
+from .get_clipit import *
