@@ -29,7 +29,7 @@ def extract_query(database_query):
                 return value
     return None
 
-from abstract_ai.gpt_classes.nogui_selection.general_query import make_general_query
+from ..gpt_classes.nogui_selection.general_query import make_general_query
 async def async_safe_excel_save(df, original_file_path, index=False, suffix=None, engine=None):
     """
     Asynchronous wrapper for safe_excel_save, running it in an executor.
